commit ddf34c3d28477689064d650e0bf4f578de75ec86
Author: Thomas Schöpping <tschoepp@cit-ec.uni-bielefeld.de>
Date:   Wed Feb 6 13:55:47 2019 +0100

    updated AMiRo-LLD and applied all required changes to AMiRo-OS and all modules.

diff --git a/modules/PowerManagement_1-1/module.h b/modules/PowerManagement_1-1/module.h
index 90c5e92..08f6b35 100644
--- a/modules/PowerManagement_1-1/module.h
+++ b/modules/PowerManagement_1-1/module.h
@@ -434,7 +434,7 @@ extern ROMCONST char* moduleShellPrompt;
 #define MODULE_INIT_TESTS() {                                                 \
   /* add unit-test shell commands */                                          \
   aosShellAddCommand(&aos.shell, &moduleUtAdcVsys.shellcmd);                  \
-  aosShellAddCommand(&aos.shell, &moduleUtAlldAt24c01bn.shellcmd);            \
+  aosShellAddCommand(&aos.shell, &moduleUtAlldAt24c01b.shellcmd);            \
   aosShellAddCommand(&aos.shell, &moduleUtAlldBq24103a.shellcmd);             \
   aosShellAddCommand(&aos.shell, &moduleUtAlldBq27500.shellcmd);              \
   aosShellAddCommand(&aos.shell, &moduleUtAlldBq27500Bq24103a.shellcmd);      \
@@ -478,7 +478,7 @@ extern ROMCONST char* moduleShellPrompt;
   moduleHalI2cSrPm18Pm33GaugeRearConfig.duty_cycle = (moduleHalI2cSrPm18Pm33GaugeRearConfig.clock_speed <= 100000) ? STD_DUTY_CYCLE : FAST_DUTY_CYCLE_2;  \
   i2cStart(&MODULE_HAL_I2C_SR_PM18_PM33_GAUGEREAR, &moduleHalI2cSrPm18Pm33GaugeRearConfig); \
   moduleHalI2cSrPm42Pm50PmVddEepromGaugeFrontConfig.clock_speed = (INA219_LLD_I2C_MAXFREQUENCY < moduleHalI2cSrPm42Pm50PmVddEepromGaugeFrontConfig.clock_speed) ? INA219_LLD_I2C_MAXFREQUENCY : moduleHalI2cSrPm42Pm50PmVddEepromGaugeFrontConfig.clock_speed; \
-  moduleHalI2cSrPm42Pm50PmVddEepromGaugeFrontConfig.clock_speed = (AT24C01BN_LLD_I2C_MAXFREQUENCY < moduleHalI2cSrPm42Pm50PmVddEepromGaugeFrontConfig.clock_speed) ? AT24C01BN_LLD_I2C_MAXFREQUENCY : moduleHalI2cSrPm42Pm50PmVddEepromGaugeFrontConfig.clock_speed; \
+  moduleHalI2cSrPm42Pm50PmVddEepromGaugeFrontConfig.clock_speed = (AT24C01B_LLD_I2C_MAXFREQUENCY < moduleHalI2cSrPm42Pm50PmVddEepromGaugeFrontConfig.clock_speed) ? AT24C01B_LLD_I2C_MAXFREQUENCY : moduleHalI2cSrPm42Pm50PmVddEepromGaugeFrontConfig.clock_speed; \
   moduleHalI2cSrPm42Pm50PmVddEepromGaugeFrontConfig.clock_speed = (BQ27500_LLD_I2C_MAXFREQUENCY < moduleHalI2cSrPm42Pm50PmVddEepromGaugeFrontConfig.clock_speed) ? BQ27500_LLD_I2C_MAXFREQUENCY : moduleHalI2cSrPm42Pm50PmVddEepromGaugeFrontConfig.clock_speed; \
   moduleHalI2cSrPm42Pm50PmVddEepromGaugeFrontConfig.duty_cycle = (moduleHalI2cSrPm42Pm50PmVddEepromGaugeFrontConfig.clock_speed <= 100000) ? STD_DUTY_CYCLE : FAST_DUTY_CYCLE_2;  \
   i2cStart(&MODULE_HAL_I2C_SR_PM42_PM50_PMVDD_EEPROM_GAUGEFRONT, &moduleHalI2cSrPm42Pm50PmVddEepromGaugeFrontConfig);  \
@@ -488,7 +488,7 @@ extern ROMCONST char* moduleShellPrompt;
   pwmStart(&MODULE_HAL_PWM_BUZZER, &moduleHalPwmBuzzerConfig);                \
   moduleHalPwmBuzzerConfig.frequency = MODULE_HAL_PWM_BUZZER.clock;           \
   pwmStop(&MODULE_HAL_PWM_BUZZER);                                            \
-  moduleHalPwmBuzzerConfig.period = moduleHalPwmBuzzerConfig.frequency / PKLCS1212E4001_LLD_FREQUENCY_SPEC; \
+  moduleHalPwmBuzzerConfig.period = moduleHalPwmBuzzerConfig.frequency / PKxxxExxx_LLD_FREQUENCY_SPEC; \
   pwmStart(&MODULE_HAL_PWM_BUZZER, &moduleHalPwmBuzzerConfig);                \
 }
 #if (BOARD_SENSORRING == BOARD_PROXIMITYSENSOR) || defined(__DOXYGEN__)
@@ -586,28 +586,28 @@ extern ROMCONST char* moduleShellPrompt;
  * @{
  */
 /*===========================================================================*/
-#include <alld_at24c01bn-sh-b.h>
-#include <alld_bq24103a.h>
+#include <alld_AT24C01B.h>
+#include <alld_bq241xx.h>
 #include <alld_bq27500.h>
-#include <alld_ina219.h>
-#include <alld_led.h>
-#include <alld_pklcs1212e4001.h>
-#include <alld_tps62113.h>
+#include <alld_INA219.h>
+#include <alld_LED.h>
+#include <alld_PKxxxExxx.h>
+#include <alld_TPS6211x.h>
 
 /**
  * @brief   EEPROM driver.
  */
-extern AT24C01BNDriver moduleLldEeprom;
+extern AT24C01BDriver moduleLldEeprom;
 
 /**
  * @brief   Battery charger (front battery) driver.
  */
-extern BQ24103ADriver moduleLldBatteryChargerFront;
+extern BQ241xxDriver moduleLldBatteryChargerFront;
 
 /**
  * @brief   Battery charger (rear battery) driver.
  */
-extern BQ24103ADriver moduleLldBatteryChargerRear;
+extern BQ241xxDriver moduleLldBatteryChargerRear;
 
 /**
  * @brief   Fuel gauge (front battery) driver.
@@ -651,15 +651,15 @@ extern LEDDriver moduleLldStatusLed;
 
 /**
  * @brief   Step down converter driver.
  * @note    Although there multiple TPS62113, those are completely identical from driver few (share the same signals).
  */
-extern TPS62113Driver moduleLldStepDownConverter;
+extern TPS6211xDriver moduleLldStepDownConverter;
 
 #if (BOARD_SENSORRING == BOARD_PROXIMITYSENSOR) || defined(__DOXYGEN__)
 
-#include <alld_mpr121.h>
-#include <alld_pca9544a.h>
-#include <alld_vcnl4020.h>
+#include <alld_MPR121.h>
+#include <alld_PCA9544A.h>
+#include <alld_VCNL4020.h>
 
 /**
  * @brief   Touch sensor driver.
@@ -690,8 +690,8 @@ extern VCNL4020Driver moduleLldProximity2;
 
 #if (BOARD_SENSORRING == BOARD_DISTANCESENSOR_VL53L0X) || defined(__DOXYGEN__)
 
-#include <alld_pcal6524.h>
-#include <alld_at42qt1050.h>
+#include <alld_PCAL6524.h>
+#include <alld_AT42QT1050.h>
 
 /**
  * @brief   GPIO extender (I2C #1) driver.
@@ -712,8 +712,8 @@ extern AT42QT1050Driver moduleLldTouch;
 
 #if (BOARD_SENSORRING == BOARD_DISTANCESENSOR_VL53L1X) || defined(__DOXYGEN__)
 
-#include <alld_pcal6524.h>
-#include <alld_at42qt1050.h>
+#include <alld_PCAL6524.h>
+#include <alld_AT42QT1050.h>
 
 /**
  * @brief   GPIO extender (I2C #1) driver.
@@ -742,15 +742,15 @@ extern AT42QT1050Driver moduleLldTouch;
 /*===========================================================================*/
 #if (AMIROOS_CFG_TESTS_ENABLE == true) || defined(__DOXYGEN__)
 #include <ut_lld_adc.h>
-#include <ut_alld_at24c01bn-sh-b.h>
-#include <ut_alld_bq24103a.h>
-#include <ut_alld_bq27500.h>
-#include <ut_alld_bq27500_bq24103a.h>
-#include <ut_alld_ina219.h>
-#include <ut_alld_led.h>
-#include <ut_alld_pklcs1212e4001.h>
-#include <ut_alld_tps62113.h>
-#include <ut_alld_tps62113_ina219.h>
+#include <ut_alld_AT24C01B_v1.h>
+#include <ut_alld_bq241xx_v1.h>
+#include <ut_alld_bq27500_v1.h>
+#include <ut_alld_bq27500_v1_bq241xx_v1.h>
+#include <ut_alld_INA219_v1.h>
+#include <ut_alld_LED_v1.h>
+#include <ut_alld_PKxxxExxx_v1.h>
+#include <ut_alld_TPS6211x_v1.h>
+#include <ut_alld_TPS6211x_v1_INA219_v1.h>
 
 /**
  * @brief   ADC unit test object.
@@ -760,7 +760,7 @@ extern aos_unittest_t moduleUtAdcVsys;
 /**
  * @brief   AT24C01BN-SH-B (EEPROM) unit test object.
  */
-extern aos_unittest_t moduleUtAlldAt24c01bn;
+extern aos_unittest_t moduleUtAlldAt24c01b;
 
 /**
  * @brief   BQ24103A (battery charger) unit test object.
@@ -804,9 +804,9 @@ extern aos_unittest_t moduleUtAlldTps62113Ina219;
 
 #if (BOARD_SENSORRING == BOARD_PROXIMITYSENSOR) || defined(__DOXYGEN__)
 
-#include <ut_alld_mpr121.h>
-#include <ut_alld_pca9544a.h>
-#include <ut_alld_vcnl4020.h>
+#include <ut_alld_MPR121_v1.h>
+#include <ut_alld_PCA9544A_v1.h>
+#include <ut_alld_VCNL4020_v1.h>
 
 /**
  * @brief   MPR121 (touch sensor) unit test object.
@@ -827,8 +827,8 @@ extern aos_unittest_t moduleUtAlldVcnl4020;
 
 #if (BOARD_SENSORRING == BOARD_DISTANCESENSOR_VL53L0X) || defined(__DOXYGEN__)
 
-#include <ut_alld_pcal6524.h>
-#include <ut_alld_at42qt1050.h>
+#include <ut_alld_PCAL6524_v1.h>
+#include <ut_alld_AT42QT1050_v1.h>
 
 /**
  * @brief   PCAL6524 (GPIO extender) unit test object.
@@ -844,8 +844,8 @@ extern aos_unittest_t moduleUtAlldAt42qt1050;
 
 #if (BOARD_SENSORRING == BOARD_DISTANCESENSOR_VL53L1X) || defined(__DOXYGEN__)
 
-#include <ut_alld_pcal6524.h>
-#include <ut_alld_at42qt1050.h>
+#include <ut_alld_PCAL6524_v1.h>
+#include <ut_alld_AT42QT1050_v1.h>
 
 /**
  * @brief   PCAL6524 (GPIO extender) unit test object.
@@ -651,15 +651,15 @@ extern LEDDriver moduleLldStatusLed;
 /**
  * @brief   Step down converter driver.
- * @note    Although there multiple TPS62113, those are completely identical from driver few (share the same signals).
+ * @note    Although there multiple TPS6211x, those are completely identical from driver few (share the same signals).
  */
